@@ -129,7 +129,7 @@ class _BaseCalibrationEvaluator:
         
         # Define calibration metrics
         self.__auroc = auroc(self.__y, self.__p)            # Area under the receiver operating curve
-        self.__brier = brier(self.__y, self.__p, True)      # Brier score scaled to [0.0 - 1.0]
+        self.__brier = brier(self.__y, self.__p,)           # Brier score
         self.__ace = None                                   # Adative calibration error
         self.__mce = None                                   # Maximum calibration error
         self.__awlc = None                                  # Area within lowess curve
@@ -163,7 +163,7 @@ class _BaseCalibrationEvaluator:
 
     @property
     def brier(self):
-        """Get the scaled brier score for the current y_true and y_pred of class instance.
+        """Get the brier score for the current y_true and y_pred of class instance.
 
         Returns
         -------
@@ -306,7 +306,7 @@ class _BaseCalibrationEvaluator:
 
         if update_awlc:
             diff = np.abs(x_nonparametric - y_nonparametric)
-            self.__awlc = integrate.trapezoid(diff, y_nonparametric) # Area within loss curve
+            self.__awlc = integrate.trapezoid(diff, x_nonparametric) # Area within loss curve
             
         return (x_nonparametric, y_nonparametric)
 
@@ -318,7 +318,7 @@ class _BaseCalibrationEvaluator:
         -------
             all_metrics: str
         """
-        metrics = {"AUROC":self.__auroc, r"$Brier_{scaled}$  ":self.__brier, "ACE":self.__ace, "MCE":self.__mce, "AWLC":self.__awlc }
+        metrics = {"AUROC":self.__auroc, "Brier":self.__brier, "ACE":self.__ace, "MCE":self.__mce, "AWLC":self.__awlc }
 
         lines = ['{:<10s}{:>8d}'.format("n",self.__n)]
         for k, v in metrics.items():
@@ -387,6 +387,7 @@ class _BaseCalibrationEvaluator:
                 Applied logistic regression. Vol. 398. John Wiley & Sons, 2013.
         ..  [9] Sturges, H. A. (1926). The choice of a class interval. 
                 Journal of the american statistical association, 21(153), 65-66.
+
         """
 
         # Check group size parameter and set accordingly
@@ -401,12 +402,29 @@ class _BaseCalibrationEvaluator:
         
         # Sort Values according to their probability
         df = df.sort_values('prob')
+        df.reset_index(inplace=True)
         
         # Group data using deciles of risks
         try:
             df['dcl'] = pd.qcut(df['prob'], self.__ngroups)
         except ValueError:
-            raise Exception("Could not create groups. Maybe try with a lower number of groups or set n_groups to 'auto'.")
+            # Most likely low variance in probabilities results in non unique bin edges
+            try:
+                # FIX -> Put some probabilities into the same group
+                df['dcl'] = pd.qcut(df['prob'].rank(method='first'), self.__ngroups)
+
+                # Get propper interval labels after applied fix
+                new_categories = {}
+                df['rank'] = df['prob'].rank(method='first')
+                #for bin in set(df.dcl):
+                    #if bin.right > len(df.prob)-1:
+                        #new_categories[bin] = pd.Interval(left=round(df.prob[int(bin.left)],3), right=round(df.prob.iloc[-1],3))
+                    #else:
+                        #new_categories[bin] = pd.Interval(left=round(df.prob[int(bin.left)],3), right=round(df.prob[int(bin.right)],3))
+                    
+                #df['dcl'] = df['dcl'].cat.rename_categories(new_categories)
+            except ValueError:
+                raise Exception("Could not create groups. Maybe try with a lower number of groups or set n_groups to 'auto'.")
         except BaseException as err:
             print(f"Unexpected {err=}, {type(err)=}")
             raise
@@ -435,9 +453,6 @@ class _BaseCalibrationEvaluator:
         ----------
         ..  [1] Hosmer Jr, David W., Stanley Lemeshow, and Rodney X. Sturdivant.
                 Applied logistic regression. Vol. 398. John Wiley & Sons, 2013.
-
-        Todo:
-            * Warn at low number of groups ( ~ at g<6 )
         """
 
         i = 0
@@ -728,7 +743,7 @@ class _BaseCalibrationEvaluator:
 
 
     # STATISTICAL TEST / PLOT : Calibration Belt
-    def calbelt(self, plot:bool=False, confLevels:list=[0.8,0.95]) -> calbelt_result:
+    def calbelt(self, plot:bool=False, subset = None, confLevels=[0.8, 0.95], alpha=0.95) -> calbelt_result:
         """Calculate the calibration belt and draw plot if desired.
         
         Parameters
@@ -736,9 +751,14 @@ class _BaseCalibrationEvaluator:
         plot: boolean, optional
             Decide if plot for calibration belt should be shown.
             Much faster calculation if set to 'false'!
-        confLevels: list, optional
-            Set the confidence intervalls for the calibration belt.
+        subset: array_like
+            An optional boolean vector specifying the subset of observations to be considered.
+            Defaults to None.
+        confLevels: list
+            A numeric vector containing the confidence levels of the calibration belt.
             Defaults to [0.8,0.95].
+        alpha: float
+            The level of significance to use.
 
         Returns
         -------
@@ -783,15 +803,12 @@ class _BaseCalibrationEvaluator:
         --------
         >>> from pycaleva import CalibrationEvaluator
         >>> ce = CalibrationEvaluator(y_test, pred_prob, outsample=True, n_groups='auto')
-        >>> ce.z_test(plot=False)
+        >>> ce.calbelt(plot=False)
         calbelt_result(statistic=1.6111330037643796, pvalue=0.4468347221346196, fig=None)
 
-        Todo:
-            * Improve Calibration belt performance (boundary calculation)
-
         """
         
-        cb = CalibrationBelt(self.__y, self.__p, self.__devel, confLevels=confLevels)
+        cb = CalibrationBelt(self.__y, self.__p, self.__devel, subset=subset, confLevels=confLevels, alpha=alpha)
         
         if plot:
             return cb.plot()
@@ -830,10 +847,9 @@ class _BaseCalibrationEvaluator:
         >>> ce = CalibrationEvaluator(y_test, pred_prob, outsample=True, n_groups='auto')
         >>> ce.calibration_plot()
 
-        Todo:
-            * LOWESS Curve does not fit in comparison to R package rms
         """
         fig, ax1 = plt.subplots(figsize=(10,6))
+        ax1.set_ylim(0.0, 1.05)
 
         # Draw a calibration plot using matplotlib only
         y_grouped = self.__ct["mean_observed"]
@@ -843,7 +859,7 @@ class _BaseCalibrationEvaluator:
         x_nonparametric,y_nonparametric = self.__nonparametric_fit(update_awlc=False)
 
         # Add calibration line for model
-        plt.scatter(p_grouped,y_grouped, marker="^", facecolors='none', edgecolors='r', label='Grouped observations')
+        plt.scatter(p_grouped,y_grouped, marker="^", facecolors='none', edgecolors='r', label=f'Grouped observations g={self.__ngroups}')
 
         # Add histogram on second axis
         h, e = np.histogram(self.__p, bins=50)
